==> nextcloud-12.0.1-1-any.pkg.tar.xz: usr/share/webapps/nextcloud/apps/activity/l10n/gl.js <==
OC.L10N.register(
    "activity",
    {
    "Activities" : "Actividades",
    "An error occurred while loading activities" : "Produciuse un erro ao cargar as actividades",
    "No activity yet" : "Aínda non houbo actividade",
    "Load more activities" : "Cargar máis actividades",
    "Copied!" : "Copiado!",
    "Not supported!" : "Non admitido!",
    "Press ⌘-C to copy." : "Prema ⌘-C para copiar.",
    "Press Ctrl-C to copy." : "Prema Ctrl-C para copiar.",
    "{name} (invisible)" : "{name} (invisíbel)",
    "{name} (restricted)" : "{name} (restrinxido)",
    "in {path}" : "en {path}",
    "This stream will show events like additions, changes & shares" : "Este fluxo amosará eventos como adicións, cambios e elementos compartidos",
    "There are no events for this filter" : "Non hai eventos neste filtro",
    "Today" : "Hoxe",
    "Yesterday" : "Onte",
    "Personal activity feed for %s" : "Fonte da actividade persoal para %s",
    "Your feed URL is invalid" : "O URL da fonte é incorrecto",
    "Your settings have been updated." : "Actualizaronse os axustes.",
    "Settings have been updated." : "Actualizáronse os axustes.",
    "Mail" : "Correo",
    "Stream" : "Fluxo",
    "All activities" : "Todas as actividades",
    "By others" : "Por outros",
    "By you" : "Por ti",
    "\"remote user\"" : "«usuario remoto»",
    "Hello %s" : "Ola %s",
    "Hello %s," : "Ola %s,",
    "There was some activity at %s" : "Houbo actividade en %s",
    "_and %n more _::_and %n more _" : ["e %n máis","e %n máis"],
    "Activity notification" : "Notificación da actividade",
    ", " : ", ",
    "%s and %s" : "%s e %s",
    "Activity" : "Actividade",
    "Activity feed" : "Fonte da actividade",
    "Configure the default activity settings for new users." : "Configure os axustes predeterminados de actividade pra novos usuarios.",
    "Choose for which activities you want to get an email notification, and which should show up in the activity app stream." : "Escolla as actividades das que quere recibir unha notificación por correo-e e as que deben aparecer na secuencia de actividades da aplicación.",
    "List your own actions in the stream" : "Amosa as súas propias accións na secuencia",
    "Notify about your own actions via email" : "Notifica as súas propias accións mediante o correo-e",
    "You need to set up your email address before you can receive notification emails." : "É necesario estabelecer o enderezo correo para poder recibir correos de notificación.",
    "Send emails:" : "Enviar os correos:",
    "Hourly" : "Cada hora",
    "Daily" : "A diario",
    "Weekly" : "Semanalmente",
    "Settings" : "Axustes",
    "Enable RSS feed" : "Activar as fontes RSS",
    "No more events to load" : "Non hai máis eventos para cargar",
    "Files" : "Ficheiros",
    "Error loading activities" : "Produciuse un erro ao cargar as actividades",
    "No activities" : "Non hai actividades",
    "You are receiving this email because the following things happened at %s" : "Recibiu este correo porque sucederon as seguintes cousas en %s",
    "* %1$s - %2$s" : "* %1$s - %2$s",
    "_* and %n more _::_* and %n more _" : ["* e %n máis ","* e %n máis "]
},
"nplurals=2; plural=(n != 1);");

==> nextcloud-12.0.2-1-any.pkg.tar.xz: usr/share/webapps/nextcloud/apps/activity/l10n/gl.js <==
OC.L10N.register(
    "activity",
    {
    "Activities" : "Actividades",
    "An error occurred while loading activities" : "Produciuse un erro ao cargar as actividades",
    "No activity yet" : "Aínda non houbo actividade",
    "Load more activities" : "Cargar máis actividades",
    "Copied!" : "Copiado!",
    "Not supported!" : "Non soportado!",
    "Press ⌘-C to copy." : "Prema ⌘-C para copiar.",
    "Press Ctrl-C to copy." : "Prema Ctrl-C para copiar.",
    "{name} (invisible)" : "{name} (invisíbel)",
    "{name} (restricted)" : "{name} (restrinxido)",
    "in {path}" : "en {path}",
    "This stream will show events like additions, changes & shares" : "Este fluxo amosará eventos como adicións, cambios e comparticións",
    "There are no events for this filter" : "Non hai eventos para este filtro",
    "Today" : "Hoxe",
    "Yesterday" : "Onte",
    "Personal activity feed for %s" : "Fonte da actividade persoal para %s",
    "Your feed URL is invalid" : "A súa URL da fonte de actividade é incorrecta",
    "Your settings have been updated." : "Actualizáronse os seus axustes.",
    "Settings have been updated." : "Actualizáronse os axustes.",
    "Mail" : "Correo",
    "Stream" : "Fluxo",
    "All activities" : "Todas as actividades",
    "By others" : "Por outros",
    "By you" : "Por ti",
    "\"remote user\"" : "«usuario remoto»",
    "Hello %s" : "Ola %s",
    "Hello %s," : "Ola %s,",
    "There was some activity at %s" : "Houbo actividade en %s",
    "Activity notification" : "Notificación de actividade",
    ", " : ", ",
    "%s and %s" : "%s e %s",
    "Activity" : "Actividade",
    "Activity feed" : "Fonte de novas actividades",
    "Configure the default activity settings for new users." : "Configure os axustes predeterminados de actividade pra novos usuarios.",
    "Choose for which activities you want to get an email notification, and which should show up in the activity app stream." : "Escolla as actividades das que quere recibir unha notificación por correo-e e as que deben aparecer na secuencia de actividades da aplicación.",
    "List your own actions in the stream" : "Amosa as súas propias accións na secuencia",
    "Notify about your own actions via email" : "Notifica as súas propias accións mediante o correo-e",
    "You need to set up your email address before you can receive notification emails." : "É necesario estabelecer o enderezo de correo-e para poder recibir correos de notificación.",
    "Send emails:" : "Enviar correos-e:",
    "Hourly" : "Cada hora",
    "Daily" : "A diario",
    "Weekly" : "Semanalmente",
    "Settings" : "Axustes",
    "Enable RSS feed" : "Activar as fontes RSS",
    "No more events to load" : "Non hai máis eventos que cargar",
    "Files" : "Ficheiros",
    "Error loading activities" : "Produciuse un erro ao cargar as actividades",
    "No activities" : "Non hai actividades",
    "You are receiving this email because the following things happened at %s" : "Recibiu este correo porque sucederon as seguintes cousas en %s",
    "* %1$s - %2$s" : "* %1$s - %2$s"
},
"nplurals=2; plural=(n != 1);");
